

import java.io.*;
import org.dom4j.*;
import java.util.HashMap;

public class JavaExcel {
    
    private File outputFile = null;
    
    /** Creates a new instance of JavaExcel */
    public JavaExcel() {
    }
    
    //This function writes the SpreadsheetML document to a file
    public void write(String file) throws Exception {
        outputFile = new File(file);
        Document doc = DocumentHelper.createDocument();
        HashMap pmap = new HashMap();
        pmap.put("progid","Excel.Sheet");
        doc.addProcessingInstruction("mso-application",pmap);
        doc.add(this.createElements());
        FileWriter out = new FileWriter(outputFile);
        doc.write(out);
        out.flush();
        out.close();
    }
    
    //This function creates the root of the SpreadsheetML and
    //populates it with necesary elements.
    private Element createElements() throws Exception {
        //Create all Elements
        Element workbook = this.createWorkbook();
        Element worksheet = this.createWorksheet("TestSheet");
        workbook.add(worksheet);
        Element table = this.createTable();
        worksheet.add(table);
        Element row1 = this.createRow("1");
        table.add(row1);
        Element cellA1 = this.createCell();
        row1.add(cellA1);
        Element dataA1 = this.createData("Number","121");
        cellA1.add(dataA1);
        Element row2 = this.createRow("2");
        table.add(row2);
        Element cellA2 = this.createCell();
        row2.add(cellA2);
        Element dataA2 = this.createData("String","121 is 11*11");
        cellA2.add(dataA2);
        return workbook;
    }
    
    private Element createWorksheet(String name) {
        Element e = DocumentHelper.createElement("Worksheet");
        e.addAttribute("ss:Name", name);
        e.setQName(new QName("Worksheet",new Namespace(null,"urn:schemas-microsoft-com:office:spreadsheet")));
        return e;
    }
    
    private Element createTable() {
        return DocumentHelper.createElement("ss:Table");
    }
    
    private Element createRow(String index) {
        Element e = DocumentHelper.createElement("ss:Row");
        e.addAttribute("ss:Index",index);
        return e;
    }
    
    private Element createCell() {
        return DocumentHelper.createElement("ss:Cell");
    }
    
    private Element createData(String type, String data) {
        Element e = DocumentHelper.createElement("ss:Data");
        e.addAttribute("ss:Type",type);
        e.setText(data);
        return e;
    }
    
    private Element createWorkbook() throws Exception {
        Element root =  DocumentHelper.createElement("Workbook");
        //Set up the necesary namespaces
        root.add(new Namespace("x","urn:schemas-microsoft-com:office:excel"));
        root.add(new Namespace("ss","urn:schemas-microsoft-com:office:spreadsheet"));
        root.setQName(new QName("Workbook",new Namespace(null,"urn:schemas-microsoft-com:office:spreadsheet")));
        return root;
    }
    
    public static void main(String[] args) {
       try{
           JavaExcel j = new JavaExcel();
           j.write("C:\\JavaExcel.xml");
       } catch(Exception e) {e.printStackTrace();}
    }
    
}
